powered by
This is an ordinary rounding function, so called round half away from zero
Round(x, n = 0)
ordinarily rounded value
numeric to be rounded
indicating decimal digits
Kyun-Seop Bae <[email protected]>
The function round in R base rounds to the even number, i.e. round(0.5) is 0 not 1. If you want rounding 0.5 be 1, you can use this Round function. This function is for the consistency with other software like MS-Excel, SAS.
round
round(0.5)
Round
See wikipedia subject "Rounding"
(x = 1:10 - 0.5) Round(x) round(x) # compare with the above
Run the code above in your browser using DataLab