This output NCA result in a rtf file.
rtfNCA(fileName = "Temp-NCA.rtf", concData, key = "Subject", colTime = "Time",
colConc = "conc", dose = 0, adm = "Extravascular", dur = 0,
doseUnit = "mg", timeUnit = "h", concUnit = "ug/L", down="Linear",
R2ADJ = 0, MW = 0, SS = FALSE, tau = NA, unitTau = "h", iAUC = "",
excludeDelta = 1, UsePoints = NULL)
maximum concentration, Cmax
dose normalized Cmax, CMAX / Dose, Cmax / Dose
time of maximum concentration, Tmax
time to observe the first non-zero concentration, for extravascular administration only
last positive concentration observed, Clast
last positive concentration predicted, Clast_pred
time of last positive concentration, Tlast
half-life by lambda z, ln(2)/LAMZ
lambda_z negative of best fit terminal slope
earliest time for LAMZ
last time for LAMZ
number of points for LAMZ
correlation of log(concentration) and time
R-squared
R-squared adjusted
back extrapolated concentration at time 0, for bolus intravascular administration only
AUC from 0 to TLST
AUC using all the given points, including trailing zero concentrations
AUC infinity observed
AUCIFO / Dose
AUC infinity predicted using CLSTP instead of CLST
AUCIFP / Dose
AUC % extrapolation observed
AUC % extrapolated for AUCIFP
AUC % back extrapolation observed, for bolus IV administration only
AUC % back extrapolation predicted with AUCIFP, for bolus IV administration only
AUMC to the TLST
AUMC infinity observed using CLST
AUMC infinity determined by CLSTP
AUMC % extrapolated observed
AUMC % extrapolated predicted
AUC over one dosing interval, from 0 to tau; with SS = TRUE only
average concentration over the dosing interval at steady state, AUCTAU / tau; with SS = TRUE only
mean residence time (MRT) to TLST, for intravascular administration
mean residence time (MRT) infinity using CLST, for intravascular administration
mean residence time (MRT) infinity using CLSTP, for intravascular administration
mean residence time (MRT) to TLST, for extravascular administration
mean residence time (MRT) infinity using CLST, for extravascular administration
mean residence time (MRT) infinity using CLSTP, for extravascular administration
volume of distribution determined by LAMZ and AUCIFO, for intravascular administration
volume of distribution determined by LAMZ and AUCIFP, for intravascular administration
VZO for extravascular administration, VZO/F, F is bioavailability
VZP for extravascular administration, VZP/F, F is bioavailability
clearance using AUCIFO, for intravascular administration
clearance using AUCIFP, for intravascular administration
CLO for extravascular administration, CLO/F, F is bioavailability
CLP for extravascular administration, CLP/F, F is bioavailability
volume of distribution at steady state using CLST, for intravascular administration only
volume of distribution at stead state using CLSTP, for intravascular administration only
file name to save
concentration data table
column names of concData to be shown in the output
column name for time
column name for concentration
administered dose, a scalar or a vector
one of "Bolus" or "Infusion" or "Extravascular" to indicate drug administration mode
duration of infusion, a scalar or a vector
unit of dose
unit of time
unit of concentration
either of "Linear" or "Log" to indicate the way to calculate AUC and AUMC
Minimum adjusted R-square value to determine terminal slope automatically
molecular weight of drug
if steady-state, this should be TRUE and tau must be given. AUCTAU (AUC over one dosing interval, 0 to tau) is then used instead of AUCIFO (AUCinf) for the calculation of Vz (VZFO, VZO), CL (CLFO, CLO), and Vdss (VSSO), and AUCTAU and CAVG are reported. The Pred-based twins (VZFP, CLFP, VZP, CLP, VSSP) and the MRT to infinity are NA at steady state. Up to NonCompart 0.8.3 AUCLST (AUClast) was used in place of AUCTAU.
dosing interval in the unit of unitTau, a positive scalar or one value per NCA (subject). Required when SS = TRUE; ignored, with a warning, otherwise.
unit of tau: "h" (default), "min", "s", "d", "wk" or their common spellings. tau is converted into timeUnit before use.
interval AUC information in a dataframe with "Name", "Start", and "End" columns. A name that equals a standard parameter name (for example "AUCTAU" together with SS = TRUE) is refused.
Improvement of R2ADJ larger than this value could exclude the last point. Default value 1 is for the compatibility with other software. Author recommends to use excludeDelta option with about 0.3.
A list of length equal to the number of subjects/NCAs. Each element is a vector of indices of points to calculate terminal slope for the corresponding subject. Values of use points should not be zero. Use only when automatic determination is not satisfactory. If this is used, R2ADJ option is ignored.
Kyun-Seop Bae <[email protected]>
help, txtNCA, pdfNCA
#rtfNCA(fileName="NCA-Theoph.rtf", Theoph, key="Subject", colTime="Time",
# colConc="conc", dose=320, doseUnit="mg", timeUnit="h", concUnit="mg/L")
#rtfNCA(fileName="NCA-Theoph.rtf", Theoph, key=c("Subject", "Wt"), colTime="Time",
# colConc="conc", dose=320, doseUnit="mg", timeUnit="h", concUnit="mg/L")
#rtfNCA(fileName="NCA-Indometh.rtf", Indometh, key="Subject", colTime="time",
# colConc="conc", adm="Infusion", dur=0.5, dose=25, doseUnit="mg",
# timeUnit="h", concUnit="mg/L")
Run the code above in your browser using DataLab