This converts the table output of sNCA to text form output.
Usage
Res2Txt(ResNCA, x, y, dose = 0, adm = "Extravascular", dur = 0, doseUnit = "mg",
down = "Linear", SS = FALSE, tau = NA, unitTau = "h")
Value
Text form output from the coversion of table form output
Arguments
ResNCA
Output table from sNCA
x
usually time, a vector
y
usually concentration, a vector
dose
given amount, a scalar
adm
one of "Bolus" or "Infusion" or "Extravascular" to indicate drug administration mode
dur
duration of infusion, a scalar
doseUnit
unit of dose
down
either of "Linear" or "Log" to indicate the way to calculate AUC and AUMC
SS
TRUE when ResNCA came from a steady-state analysis (SS = TRUE in sNCA); the report then states the dosing interval the AUCTAU, CAVG, CL and Vz values were computed over
tau
dosing interval as given to sNCA, printed in the Calculation Setting section when SS = TRUE
x = Theoph[Theoph$Subject=="1","Time"]
y = Theoph[Theoph$Subject=="1","conc"]
z = NonCompart::sNCA(x, y, dose=320, doseUnit="mg", concUnit="mg/L", timeUnit="h")
Res2Txt(z, x, y)